<?php

namespace Drupal\permanent_entities\Commands;

use Drush\Commands\DrushCommands;
use Drupal\permanent_entities\Entity\PermanentEntity;
use Drupal\permanent_entities\Entity\PermanentEntityType;

/**
 * Drush command to create Permanent Entities.
 */
class PermanentEntitiesCommands extends DrushCommands {

  /**
   * Creates a permenent entity.
   *
   * @param $type
   *   The permanent entity type
   * @param $id
   *   The permanent entity id
   * @param $label
   *   The permanent entity label.
   * @usage drush pec planet jupiter Jupiter
   *   Creates a planet with id jupiter and label Jupiter
   *
   * @command permanent:entity-create
   * @aliases pec,permanent-entity-create
   */
  public function entityCreate($type, $id, $label) {

    if (empty($type)) {
      throw new \Exception('The permanent entity type is required');
    }
    if (empty($id)) {
      throw new \Exception('The permanent entity id is required');
    }
    if (empty($label)) {
      throw new \Exception('The permanent entity label is required');
    }

    if (!PermanentEntityType::load($type)) {
      throw new \Exception(dt('The permanent entity type "@type" does not exist.', ['@type' => $type]));
    }

    if (!empty(PermanentEntity::load($id))) {
      throw new \Exception(dt('The permanent entity type "@type" with id: @id already exist.', ['@type' => $type, '@id' => $id]));
    }
    PermanentEntity::create([
      'label' => $label,
      'id' => $id,
      'type' => $type,
    ])->save();

    $this->output()->writeln(dt('Permanent entity: "@id" created', ['@id' => $id]));
  }

}
